==> paraview-5.12.0-6-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/AnalyzeNIfTIReaderWriter-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_depends" "VTK::IOImage")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::zlib")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_library_name" "vtkAnalyzeNIfTIIO")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkAnalyzeReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkAnalyzeWriter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkNIfTIReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkNIfTIWriter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkAnalyzeNIfTIIOModule.h")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/AnalyzeNIfTIReaderWriter/vtk/hierarchy/AnalyzeNIfTIReaderWriter/vtkAnalyzeNIfTIIO-hierarchy.txt")
unset(_vtk_module_import_prefix)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/AnalyzeNIfTIReaderWriter-vtk-module-properties.cmake <==
set(_vtk_module_import_prefix "${CMAKE_CURRENT_LIST_DIR}")
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
get_filename_component(_vtk_module_import_prefix "${_vtk_module_import_prefix}" DIRECTORY)
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_exclude_wrap" "FALSE")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_include_marshal" "FALSE")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_depends" "VTK::IOImage")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_private_depends" "VTK::CommonCore;VTK::CommonDataModel;VTK::zlib")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_optional_depends" "")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_implements" "")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_implementable" "FALSE")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_library_name" "vtkAnalyzeNIfTIIO")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_headers" "${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkAnalyzeReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkAnalyzeWriter.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkNIfTIReader.h;${_vtk_module_import_prefix}/include/paraview/ParaView_paraview_plugins/vtkNIfTIWriter.h")
set_property(TARGET "AnalyzeNIfTIIO::NIfTIIO" PROPERTY "INTERFACE_vtk_module_hierarchy" "${_vtk_module_import_prefix}/lib/paraview/plugins/AnalyzeNIfTIReaderWriter/vtk/hierarchy/AnalyzeNIfTIReaderWriter/vtkAnalyzeNIfTIIO-hierarchy.txt")
unset(_vtk_module_import_prefix)
